Configuration class

Constructors

Configuration()

Properties

hashCode → int
The hash code for this object.
no setterinherited
homeActions ↔ List<ShakeBaseAction>?
getter/setter pair
onShakeDismiss ↔ Function?
getter/setter pair
onShakeOpen ↔ Function?
getter/setter pair
onShakeSubmit ↔ dynamic Function(String, Map<String, String>)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadMessagesListener ↔ UnreadMessagesListener?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited