ShakeBaseAction class abstract

Represents base action for Home screen.

Implementers

Constructors

ShakeBaseAction(String? title, String? subtitle, String? icon, Function? handler, String? type)

Properties

handler ↔ Function?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
getter/setter pair
iconRes ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
getter/setter pair
subtitleRes ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
titleRes ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited