ShakeForm class

Represents Shake form.

Constructors

ShakeForm(List<ShakeFormComponent> components)

Properties

components ↔ List<ShakeFormComponent>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts object to map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map data) → ShakeForm
Converts map to object.