ShakePickerItem class

Represents Shake form Picker item.

Constructors

ShakePickerItem(String key, String? text, {String? icon, String? tag, String? textRes, String? iconRes})

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
getter/setter pair
iconRes ↔ String?
getter/setter pair
key ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
getter/setter pair
text ↔ String?
getter/setter pair
textRes ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts object to map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map data) → ShakePickerItem
Converts map to object.