ShakeTheme class

Represents Shake UI theme.

Constructors

ShakeTheme()

Properties

accentColor ↔ String?
getter/setter pair
accentTextColor ↔ String?
getter/setter pair
backgroundColor ↔ String?
getter/setter pair
borderRadius ↔ double?
getter/setter pair
elevation ↔ double?
getter/setter pair
fontFamilyBold ↔ String?
getter/setter pair
fontFamilyMedium ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
outlineColor ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryBackgroundColor ↔ String?
getter/setter pair
secondaryTextColor ↔ String?
getter/setter pair
shadowOffset ↔ Offset?
getter/setter pair
shadowOpacity ↔ double?
getter/setter pair
shadowRadius ↔ double?
getter/setter pair
textColor ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts object to map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited