ShakeHttpLogger class

Parser and logger for dart:io network requests.

Constructors

ShakeHttpLogger()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(HttpClientRequest request, {String? requestBody}) → void
onResponse(HttpClientRequest request, HttpClientResponse response, {String? responseBody}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited